@@ -107,7 +107,8 @@ gboolean		gnome_cups_printer_get_attributes_initialized (GnomeCupsPrinter
 
 /* Status and attributes */
 
-const char *            gnome_cups_printer_get_uri           (GnomeCupsPrinter        *printer);
+const char *            gnome_cups_printer_get_uri           (GnomeCupsPrinter const *printer);
+const char *		gnome_cups_printer_get_device_uri    (GnomeCupsPrinter const *printer);
 
 ipp_pstate_t            gnome_cups_printer_get_state         (GnomeCupsPrinter        *printer);
 const char        *     gnome_cups_printer_get_state_name    (GnomeCupsPrinter        *printer);
